@@ -30,7 +30,7 @@ try:
 except:
     from newsletter import base
 
-class TestImageops(unittest.TestCase):
+class TestNewsletter(unittest.TestCase):
 
 
     def test_nothing(self):
